/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch das
 * Ministerium für Energiewende, Klimaschutz, Umwelt und Natur
 * Zentrales IT-Management
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.formcycle.errorhandling;

import static java.util.Objects.*;

import de.ozgcloud.formcycle.OzgCloudConfig;
import lombok.Setter;

@Setter
public class OzgCloudRequestException extends TechnicalException {

	private OzgCloudConfig ozgCloudConfig; // NOSONAR

	public OzgCloudRequestException(String message) {
		super(message);
	}

	public OzgCloudRequestException(String message, Throwable cause) {
		super(message, cause);
	}

	public OzgCloudRequestException(String message, String exceptionId) {
		super(message, exceptionId);
	}

	public OzgCloudRequestException(String msg, OzgCloudConfig ozgCloudConfig, Throwable cause) {
		super(msg, cause);
		this.ozgCloudConfig = ozgCloudConfig;
	}

	public String getMessageWithConfig() {
		var messageBuilder = new StringBuilder(super.getMessage());
		if (isNull(ozgCloudConfig)) {
			return messageBuilder.toString();
		}
		messageBuilder.append("\nPlugin configuration:\n")
				.append("\t").append(OzgCloudConfig.KEY_EINGANGSADAPTER_URL).append(": ").append(ozgCloudConfig.getEingangsAdapterUrl());
		if (nonNull(ozgCloudConfig.getProxyConfig())) {
			messageBuilder.append("\n\t").append(ozgCloudConfig.getProxyConfig());
		}
		return messageBuilder.toString();
	}
}
