/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch das
 * Ministerium für Energiewende, Klimaschutz, Umwelt und Natur
 * Zentrales IT-Management
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.formcycle;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.NullAndEmptySource;
import org.junit.jupiter.params.provider.ValueSource;
import org.mockito.InjectMocks;

class PortParserTest {

	@InjectMocks
	private PortParser portParser;

	@DisplayName("should throw exception when")
	@ParameterizedTest(name = "port property is \"{0}\"")
	@ValueSource(strings = { "-1", "0", "65536", "abs" })
	void shouldReturnNull(String portProperty) {
		Assertions.assertThrows(IllegalArgumentException.class, () -> portParser.parse(portProperty));
	}

	@DisplayName("should return null when")
	@ParameterizedTest(name = "port property is \"{0}\"")
	@NullAndEmptySource
	@ValueSource(strings = { " " })
	void shouldReturnNullWhenPortPropertyIsBlank(String portProperty) {
		var port = portParser.parse(portProperty);

		assertThat(port).isNull();
	}

	@Test
	void shouldReturnPort() {
		var result = portParser.parse("1");

		assertThat(result).isEqualTo(1);
	}

}